﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MontoyaTech.MySqlPlus
{
    /// <summary>
    /// The outline of a MySqlRowIndex attribute which allows the specification
    /// of an index for a row.
    /// </summary>
    [AttributeUsage(AttributeTargets.Class | AttributeTargets.Struct, AllowMultiple = true, Inherited = true)]
    public class MySqlRowIndex : Attribute
    {
        /// <summary>
        /// The name of this index. Default is null. If null, one will be created automatically.
        /// </summary>
        public string Name = null;

        /// <summary>
        /// The name of the columns that belong to this index.
        /// </summary>
        public string[] Columns = null;

        /// <summary>
        /// Creates a new default MySqlRowIndex.
        /// </summary>
        public MySqlRowIndex() { }

        /// <summary>
        /// Creates a new default MySqlRowIndex with column names apart of the index.
        /// </summary>
        /// <param name="columns"></param>
        /// <exception cref="ArgumentException"></exception>
        public MySqlRowIndex(params string[] columns)
        {
            if (columns == null || columns.Length == 0)
                throw new ArgumentException("Columns must not be null or 0.");

            this.Columns = columns;
        }
    }
}
